@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+import hashlib
 import os
 
 
@@ -17,8 +17,10 @@ def mktree(newdir):
         os.makedirs(newdir)
 
 
-def clean_url(method, url):
-    return f"{method}_{url.strip('.').replace('/', '_')}"
+def clean_url(method, url, data=''):
+    if not isinstance(data, (str, bytes)):
+        data = hashlib.sha256(str(data).encode()).hexdigest()
+    return f"{url.strip('.').replace('/', '_')}/{method}/{str(data)}"
 
 
 def get_filename(base, name):
